#
# spec file for package portmidi
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1590
%bcond_without java
%else
%bcond_with    java
%endif

%define soname  2
Name:           portmidi
Version:        2.0.4
Release:        2.4
Summary:        Real-time MIDI input/output audio tools
License:        MIT
Group:          Productivity/Multimedia/Sound/Midi
URL:            https://github.com/PortMidi/portmidi
Source:         https://github.com/PortMidi/portmidi/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  alsa-devel >= 0.9
BuildRequires:  gcc-c++
# we can reduce the minimum cmake version, if not building the java bindings
%if %{with java}
BuildRequires:  cmake >= 3.21
BuildRequires:  java-devel >= 11
%else
BuildRequires:  cmake >= 3.20
Obsoletes:      portmidi-java <= %{version}-%{release}
%endif
Requires:       libportmidi%{soname} = %{version}

%description
PortMidi -- real-time MIDI input/output.
This package contains some command-line applications to test, configure and use
midi devices through PortMidi.

%package -n libportmidi%{soname}
Summary:        Real-time MIDI input/output audio library
Group:          System/Libraries
Recommends:     timidity

%description -n libportmidi%{soname}
PortMidi -- a library for real-time MIDI input/output audio.
This package contains the shared library that is required at runtime for every
application that uses PortMidi.

%package devel
Summary:        Real-time MIDI input/output audio library
Group:          Development/Libraries/Other
Requires:       libportmidi%{soname} = %{version}

%description devel
PortMidi -- real-time MIDI input/output.
This package contains the development environment to build applications and
other libraries that use PortMidi.

%package java
Summary:        Java native bindings for %{name}
Group:          Development/Libraries/Java
Requires:       java
Requires:       libportmidi%{soname} = %{version}

%description java
PortMidi -- real-time MIDI input/output.
This package contains bindings to use %{name} from Java.

%prep
%autosetup -p1
find -type f -iname \*.txt -print0 | xargs -r0 chmod a-x
find -type f -iname \*.txt -print0 | xargs -r0 perl -p -i -e 's|\r\n|\n|g'

%if ! %{with java}
sed -i 's|cmake_minimum_required(VERSION 3.21)|cmake_minimum_required(VERSION 3.20)|' CMakeLists.txt
%endif

%build
%cmake \
  %if %{with java}
  -DBUILD_JAVA_NATIVE_INTERFACE:BOOL=ON \
  -DBUILD_PMDEFAULTS:BOOL=ON \
  %endif
  -DBUILD_PORTMIDI_TESTS:BOOL=ON \
  -DCMAKE_SKIP_BUILD_RPATH=ON
%cmake_build

%install
%cmake_install
pushd build
for binary in $(find pm_test/ -maxdepth 1 -type f -executable) ; do
  bin="$(basename ${binary})"
  install -D -m 0755 "${binary}" %{buildroot}%{_bindir}/portmidi-${bin}
done
popd

%if %{with java}
install -D -m 0644 pm_java/pmdefaults/pmdefaults.jar %{buildroot}%{_javadir}/pmdefaults.jar
cat > %{buildroot}%{_bindir}/pmdefaults <<EOF
#!/bin/bash
exec java -jar "@@JAVADIR@@/pmdefaults.jar" "$@" >/dev/null
EOF
chmod a+rx %{buildroot}%{_bindir}/pmdefaults
%endif

%post   -n libportmidi%{soname} -p /sbin/ldconfig
%postun -n libportmidi%{soname} -p /sbin/ldconfig

%files
%{_bindir}/portmidi-fast
%{_bindir}/portmidi-fastrcv
%{_bindir}/portmidi-latency
%{_bindir}/portmidi-midiclock
%{_bindir}/portmidi-midithread
%{_bindir}/portmidi-midithru
%{_bindir}/portmidi-mm
%{_bindir}/portmidi-multivirtual
%{_bindir}/portmidi-pmlist
%{_bindir}/portmidi-qtest
%{_bindir}/portmidi-recvvirtual
%{_bindir}/portmidi-sendvirtual
%{_bindir}/portmidi-sysex
%{_bindir}/portmidi-testio
%{_bindir}/portmidi-virttest

%files -n libportmidi%{soname}
%license license.txt
%doc README.txt pm_linux/README_LINUX.txt
%{_libdir}/libportmidi.so.*

%files devel
%{_libdir}/libportmidi.so
%{_includedir}/portmidi.h
%{_includedir}/pmutil.h
%{_includedir}/porttime.h
%{_libdir}/cmake/PortMidi/
%{_libdir}/pkgconfig/portmidi.pc

%post   java -p /sbin/ldconfig
%postun java -p /sbin/ldconfig

%if %{with java}
%files java
%{_bindir}/pmdefaults
%{_libdir}/libpmjni.so*
%{_javadir}/pmdefaults.jar
%endif

%changelog
* Fri Dec 30 2022 Hans-Peter Jansen <hpj@urpla.net>
- If we don't build the java bindings, we can reduce the minimum
  cmake version to a level, that allows building for current Leaps
* Thu Oct 13 2022 Dirk Müller <dmueller@suse.com>
- update to 2.0.4:
  This release adjusts the data rate limit imposed on MIDI through macOS IAC
  bus to avoid losing data (this is a macOS limitation, not a PortMidi
  limitation). Apparently, the limit was significantly dropped somewhere around
  macOS 12. This release is tested on Apple M2 in addition to Linux, Win32, and
  macOS Intel. It also includes a working but not complete port to Haiku.
- drop 0001-Add-missing-return-type.patch,
  0001-changing-path-to-pm_common-directory-in-file-pm_comm.patch
  0001-Adding-missing-file-to-repo.patch: upstream
* Wed Aug 10 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Disable RPATH in the .spec
* Mon May  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.0.3
  * This version allows multiple hardware devices to have the same
    name.
- Add upstream changes:
  * 0001-Adding-missing-file-to-repo.patch
  * 0001-changing-path-to-pm_common-directory-in-file-pm_comm.patch
  * 0001-Add-missing-return-type.patch
* Mon Jan  3 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.0.2
  - build system fixes
- drop 7ed4da65ff67fa2b22eccd88beb743bd2dff6bfb.patch
- require cmake >= 3.21
* Fri Dec 31 2021 Marcus Rueckert <mrueckert@suse.de>
- restore the java package with the pmdefaults app
  7ed4da65ff67fa2b22eccd88beb743bd2dff6bfb.patch
- restore test tools again
* Thu Dec 30 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.0.1
  PortMidi has a new extended API with Pm_CreateVirtualInput(),
  Pm_CreateVirtualOutput(), and Pm_DeleteVirtualDevice() so we are
  calling this major version 2. Other changes include:
  - More careful rate limiting on macOS to allow faster IO to real
  devices, while still limiting flow through IAC bus and virtual
  ports that might cause macOS to drop messages.
  - Many updates to CMake files, including install and package
  functions.
  - Elimination of scorealign, portsmf, and PortMidi support for
  several other languages. (We'll try to maintain links to active
  projects or host language support in separate repos within this
  PortMidi project.)
  - Only basic support for Java and PmDefaults program. Current plan
  is to eliminate PmDefaults, Pm_GetDefaultInputDeviceID(), and
  Pm_GetDefaultOutputDeviceID() at the end of 2022, moving
  jportmidi and pmjni library to another repo unless users
  complain. Unfortunately, operating systems never introduced
  preferred MIDI devices analogous to preferred Audio devices.
  - A few other bug fixes such as Unicode handling are now included.
- drop patches from upstream:
  portmidi-fix_build.patch
  portmidi-fix_java_cmake.patch
  portmidi-fix_pmdefaults_startup_script.patch
- drop rpmlintrc as we no longer need it
- modernize spec file
- drop java subpackage for now
* Mon Aug 25 2014 cornelis@solcon.nl
- Correct license to MIT
- Include license file in %%doc
- Weeaken timidity requires to recommends
* Fri Dec 14 2012 joop.boonen@opensuse.org
- Add Requirement for timidity as most sound cards don't
  have a dedicated midi device anymore
- Build with libporttime.so fix needed for lenmus
* Wed Jun  6 2012 prusnak@opensuse.org
- imported from Packman to OBS
- don't ship static library
* Tue Dec 27 2011 pascal.bleser@opensuse.org
- fix build on >= 12.1
* Sun Feb 27 2011 pascal.bleser@opensuse.org
- update to version 217
- complete spec file rewrite, moved to cmake
* Mon Nov 17 2008 joop.boonen@opensuse.org
- creating package in OBS
* Tue Apr  3 2007 nando@ccrma.stanford.edu
- add -fPIC flag for x86_64 build
* Sun Apr  1 2007 nando@ccrma.stanford.edu
- build on fc6
* Sat Nov 19 2005 nando@ccrma.stanford.edu
- added patch to link libporttime to the pthreads library, otherwise
  it can't be loaded independently of libportmidi
* Thu Nov 10 2005 nando@ccrma.stanford.edu
- added Debian patches to build shared libraries neede by Common Music
* Mon Nov  7 2005 nando@ccrma.stanford.edu
- first build for Planet CCRMA, from Thac's spec file
- just create "portmidi" (follow naming in Fedora for "portaudio")
- probably should add test programs
- todo: use Debian patches to make shared libraries...
* Wed Sep 28 2005 tobbe@nyvalls.se
- Fix spec
* Wed Sep  7 2005 tobbe@nyvalls.se
- Rebuilt for le2005
* Tue Aug 23 2005 oc2pus@arcor.de
- included patch from freecycle to avoid memory leak
* Wed Apr 20 2005 oc2pus@arcor.de
- initial build for SuSE
